==> ensmallen-0.6.0-cp37-cp37m-manylinux2010_x86_64.whl: ensmallen/datasets/networkrepository/camathscinet.py <==
"""
This file offers the methods to automatically retrieve the graph ca-MathSciNet.

The graph is automatically retrieved from the NetworkRepository repository. 


References
---------------------
Please cite the following if you use the data:

```latex
@inproceedings{nr,
    title = {The Network Data Repository with Interactive Graph Analytics and Visualization},
    author={Ryan A. Rossi and Nesreen K. Ahmed},
    booktitle = {AAAI},
    url={http://networkrepository.com},
    year={2015}
}

@article{palla2008fundamental,
        title={Fundamental statistical features and self-similar properties of tagged networks},
        author={Palla, Gergely and Farkas, Ill{\'e}s J and Pollner,
P{\'e}ter and Der{\'e}nyi,
Imre and Vicsek, Tam{\'a}s},
        journal={New Journal of Physics},
        volume={10},
        number={12},
        pages={123026},
        year={2008},
        publisher={IOP Publishing}
}
```
"""
from typing import Dict

from ..automatic_graph_retrieval import AutomaticallyRetrievedGraph
from ...ensmallen import EnsmallenGraph  # pylint: disable=import-error


def CaMathscinet(
    directed: bool = False,
    preprocess: bool = True,
    verbose: int = 2,
    cache: bool = True,
    cache_path: str = "graphs/networkrepository",
    version: str = "latest",
    **additional_graph_kwargs: Dict
) -> EnsmallenGraph:
    """Return new instance of the ca-MathSciNet graph.

    The graph is automatically retrieved from the NetworkRepository repository.	

    Parameters
    -------------------
    directed: bool = False,
        Wether to load the graph as directed or undirected.
        By default false.
    preprocess: bool = True,
        Whether to preprocess the graph to be loaded in 
        optimal time and memory.
    verbose: int = 2,
        Wether to show loading bars during the retrieval and building
        of the graph.
    cache: bool = True,
        Whether to use cache, i.e. download files only once
        and preprocess them only once.
    cache_path: str = "graphs",
        Where to store the downloaded graphs.
    version: str = "latest",
        The version of the graph to retrieve.	
    additional_graph_kwargs: Dict,
        Additional graph kwargs.

    Returns
    -----------------------
    Instace of ca-MathSciNet graph.

	References
	---------------------
	Please cite the following if you use the data:
	
	```latex
	@inproceedings{nr,
	    title = {The Network Data Repository with Interactive Graph Analytics and Visualization},
	    author={Ryan A. Rossi and Nesreen K. Ahmed},
	    booktitle = {AAAI},
	    url={http://networkrepository.com},
	    year={2015}
	}
	
	@article{palla2008fundamental,
	        title={Fundamental statistical features and self-similar properties of tagged networks},
	        author={Palla, Gergely and Farkas, Ill{\'e}s J and Pollner,
	P{\'e}ter and Der{\'e}nyi,
	Imre and Vicsek, Tam{\'a}s},
	        journal={New Journal of Physics},
	        volume={10},
	        number={12},
	        pages={123026},
	        year={2008},
	        publisher={IOP Publishing}
	}
	```
    """
    return AutomaticallyRetrievedGraph(
        graph_name="CaMathscinet",
        repository="networkrepository",
        version=version,
        directed=directed,
        preprocess=preprocess,
        verbose=verbose,
        cache=cache,
        cache_path=cache_path,
        additional_graph_kwargs=additional_graph_kwargs
    )()

==> ensmallen-0.6.1-cp37-cp37m-manylinux2010_x86_64.whl: ensmallen/datasets/networkrepository/camathscinet.py <==
"""
This file offers the methods to automatically retrieve the graph ca-MathSciNet.

The graph is automatically retrieved from the NetworkRepository repository. 


References
---------------------
Please cite the following if you use the data:

```latex
@inproceedings{nr,
    title = {The Network Data Repository with Interactive Graph Analytics and Visualization},
    author={Ryan A. Rossi and Nesreen K. Ahmed},
    booktitle = {AAAI},
    url={http://networkrepository.com},
    year={2015}
}

@article{palla2008fundamental,
        title={Fundamental statistical features and self-similar properties of tagged networks},
        author={Palla, Gergely and Farkas, Ill{\'e}s J and Pollner,
P{\'e}ter and Der{\'e}nyi,
Imre and Vicsek, Tam{\'a}s},
        journal={New Journal of Physics},
        volume={10},
        number={12},
        pages={123026},
        year={2008},
        publisher={IOP Publishing}
}
```
"""
from typing import Dict

from ..automatic_graph_retrieval import AutomaticallyRetrievedGraph
from ...ensmallen import Graph  # pylint: disable=import-error


def CaMathscinet(
    directed: bool = False,
    preprocess: bool = True,
    verbose: int = 2,
    cache: bool = True,
    cache_path: str = "graphs/networkrepository",
    version: str = "latest",
    **additional_graph_kwargs: Dict
) -> Graph:
    """Return new instance of the ca-MathSciNet graph.

    The graph is automatically retrieved from the NetworkRepository repository.	

    Parameters
    -------------------
    directed: bool = False,
        Wether to load the graph as directed or undirected.
        By default false.
    preprocess: bool = True,
        Whether to preprocess the graph to be loaded in 
        optimal time and memory.
    verbose: int = 2,
        Wether to show loading bars during the retrieval and building
        of the graph.
    cache: bool = True,
        Whether to use cache, i.e. download files only once
        and preprocess them only once.
    cache_path: str = "graphs",
        Where to store the downloaded graphs.
    version: str = "latest",
        The version of the graph to retrieve.	
    additional_graph_kwargs: Dict,
        Additional graph kwargs.

    Returns
    -----------------------
    Instace of ca-MathSciNet graph.

	References
	---------------------
	Please cite the following if you use the data:
	
	```latex
	@inproceedings{nr,
	    title = {The Network Data Repository with Interactive Graph Analytics and Visualization},
	    author={Ryan A. Rossi and Nesreen K. Ahmed},
	    booktitle = {AAAI},
	    url={http://networkrepository.com},
	    year={2015}
	}
	
	@article{palla2008fundamental,
	        title={Fundamental statistical features and self-similar properties of tagged networks},
	        author={Palla, Gergely and Farkas, Ill{\'e}s J and Pollner,
	P{\'e}ter and Der{\'e}nyi,
	Imre and Vicsek, Tam{\'a}s},
	        journal={New Journal of Physics},
	        volume={10},
	        number={12},
	        pages={123026},
	        year={2008},
	        publisher={IOP Publishing}
	}
	```
    """
    return AutomaticallyRetrievedGraph(
        graph_name="CaMathscinet",
        repository="networkrepository",
        version=version,
        directed=directed,
        preprocess=preprocess,
        verbose=verbose,
        cache=cache,
        cache_path=cache_path,
        additional_graph_kwargs=additional_graph_kwargs
    )()
